resource "kubernetes_deployment" "aws_cluster_autoscaler_deployment" {
  metadata {
    name      = "aws-cluster-autoscaler"
    namespace = "kube-system"

    labels {
      app = "aws-cluster-autoscaler"
    }
  }

  spec {
    replicas = 1

    selector {
      match_labels {
        app      = "aws-cluster-autoscaler"
        instance = "aws-cluster-autoscaler-deploy"
      }
    }

    template {
      metadata {
        labels {
          app      = "aws-cluster-autoscaler"
          instance = "aws-cluster-autoscaler-deploy"
        }

        annotations {
          "iam.amazonaws.com/role" = "kube2iam-role"
        }
      }

      spec {
        service_account_name             = "cluster-autoscaler-svc-acc"
        termination_grace_period_seconds = 60

        volume {
          name = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"

          secret {
            secret_name = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"
          }
        }

        container {
          image             = "amazon/aws-alb-ingress-controller:v1.1.0"
          name              = "aws-alb-ingress-container"
          image_pull_policy = "IfNotPresent"
          args              = ["--cluster-name=${var.customer}-${var.envname}"]

          volume_mount {
            mount_path = "/var/run/secrets/kubernetes.io/serviceaccount"
            name       = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"
            read_only  = true
          }

          port {
            name           = "health"
            container_port = 10254
            protocol       = "TCP"
          }
        }
      }
    }
  }
}

resource "kubernetes_service" "cluster_autoscale_service" {
  metadata {
    name = "cluster-autoscaler"
  }

  spec {
    port {
      port        = 8085
      protocol    = "TCP"
      target_port = 8085
      name        = "HTTP"
    }

    selector {
      app = "aws-cluster-autoscaler"
    }

    type = "ClusterIP"
  }
}
